@@ -40,6 +40,7 @@ optional arguments:
   --build-dirs-path    Path for writing build files and artifacts (default: parent directory)
   --distribution       Linux distribution to build in (default: debian:sid)
   --container-command  container command to use (default: podman)
+  --host-architecture  host architecture to use when performing a cross build
   --skip-sources       build only binaries and skip creating a source
                        tarball to make the build slightly faster
                        ('debcraft build' only)
@@ -48,7 +49,7 @@ optional arguments:
                        ('debcraft release' only)
   --pull               ensure container base is updated
   --copy               perform the build on a copy of the package directory
-  --clean              ensure sources are clean
+  --clean              ensure sources are clean before and after build
   --debug              emit debug information
   -h, --help           display this help and exit
   --version            display version and exit
@@ -112,6 +113,9 @@ source "$DEBCRAFT_LIB_DIR/container/output.inc.sh"
 # shellcheck source=src/distributions.inc.sh
 source "$DEBCRAFT_LIB_DIR/distributions.inc.sh"
 
+# shellcheck source=src/generic.inc.sh
+source "$DEBCRAFT_LIB_DIR/generic.inc.sh"
+
 if [ -z "$1" ]
 then
   log_error "Missing argument <build|validate|test|release|shell|prune>"
@@ -126,15 +130,22 @@ do
   case "$1" in
     --build-dirs-path)
       export BUILD_DIRS_PATH="$2"
+      log_debug "Using BUILD_DIRS_PATH=$2"
       shift 2
       ;;
     --distribution)
       # The value is the next argument, e.g. '--distribution bookworm'
       export DISTRIBUTION="$2"
+      log_debug "Using DISTRIBUTION=$2"
       shift 2
       ;;
     --container-command)
       export CONTAINER_CMD="$2"
+      log_debug "Using CONTAINER_CMD=$2"
+      shift 2
+      ;;
+    --host-architecture)
+      export HOST_ARCH="$2"
       shift 2
       ;;
     --skip-sources)
@@ -338,16 +349,8 @@ fi
 # @TODO: If repository is a git clone, but not a `gbp clone`, it can be converted
 # to gbp with `gbp pull --verbose --ignore-branch --pristine-tar --track-missing`
 
-# Make sure sources are clean
-if [ -n "$CLEAN" ] && [ -d "$PWD/.git" ]
-then
-  log_info "Ensure git repository is clean and reset (including submodules)"
-  git clean -fdx
-  git submodule foreach --recursive git clean -fdx
-  git reset --hard
-  git submodule foreach --recursive git reset --hard
-  git submodule update --init --recursive
-fi
+# Clean up before the build if applicable
+reset_if_source_repository_and_option_clean
 
 # Configure program behaviour after user options and arguments have been parsed
 # shellcheck source=src/config-package.inc.sh
@@ -390,3 +393,6 @@ case "$ACTION" in
     source "$DEBCRAFT_LIB_DIR/prune.inc.sh"
     ;;
 esac
+
+# Clean up after a successful build if applicable
+reset_if_source_repository_and_option_clean
