@@ -16,9 +16,6 @@ source "/output.inc.sh"
 # are supposed to use it
 export DPKG_COLORS="always"
 
-# Use environment if set, otherwise use nice defaults
-log_info "DEB_BUILD_OPTIONS set as '$DEB_BUILD_OPTIONS'"
-
 # Prepare stats and cache
 BUILD_START_TIME="$EPOCHSECONDS"
 ccache --zero-stats > /dev/null
@@ -38,18 +35,37 @@ then
 else
   # Skip generating source package to make (binary) build faster by default
   DPKG_BUILDPACKAGE_ARGS="--build=any,all"
-  GBP_ARGS="--git-no-create-orig"
+  GBP_ARGS="--git-no-create-orig --git-ignore-new"
 
   # Normally dpkg-source applies the patches, but when running a binary-only
   # build directly in the Debian packaging git repository dpkg-source will be
-  # skipped and sources will remain unpatched
+  # skipped and sources will remain unpatched unless they are explicitly patched
+  # with Quilt
   if [ -f debian/patches/series ]
   then
-    log_warn "Debian patches are *not* applied as this is a binary-only build that omits invoking 'dpkg-source'."
-    log_warn "Run 'gbp pq import --force' or equivalent to apply patches before building."
+    log_info "Apply patches with Quilt"
+    export QUILT_PATCHES=debian/patches
+    quilt push -a
   fi
 fi
 
+if [ -n "$HOST_ARCH" ] && ! dpkg-architecture -e "$HOST_ARCH"
+then
+  # Apply host architecture to build process if not the same as build architecture
+  DPKG_BUILDPACKAGE_ARGS="$DPKG_BUILDPACKAGE_ARGS --host-arch $HOST_ARCH"
+  # Set default variables so cross compiling is easier. DEB_BUILD_* properties
+  # are only set here if not already set prior.  This matches what sbuild does
+  # when it performs a cross build.
+  # https://salsa.debian.org/debian/sbuild/-/blob/archive/debian/0.89.0/lib/Sbuild/Build.pm?ref_type=tags#L2886-2895
+  # https://salsa.debian.org/debian/sbuild/-/blob/archive/debian/0.89.0/lib/Sbuild/Conf.pm?ref_type=tags#L167-177
+  export CONFIG_SITE=/etc/dpkg-cross/cross-config.$HOST_ARCH
+  export DEB_BUILD_OPTIONS=${DEB_BUILD_OPTIONS:-nocheck}
+  export DEB_BUILD_PROFILES=${DEB_BUILD_PROFILES:-cross nocheck}
+fi
+
+# Use environment if set, otherwise use nice defaults
+log_info "DEB_BUILD_OPTIONS set as '$DEB_BUILD_OPTIONS'"
+
 # Teach user what is done and why
 log_info "Running 'dpkg-buildpackage --build=any,all' to create .deb packages"
 
@@ -63,12 +79,16 @@ then
   # Instead use dpkg-buildpackage directly (debuild would use it anyway) and also
   # instruct it to only build binary packages, skipping source package generation
   # and skipping related cleanup steps.
+  log_info "Running 'gbp buildpackage $GBP_ARGS' to create .deb packages from git repository"
+  # shellcheck disable=SC2086 # intentionally pass variable that can be multiple arguments
   gbp buildpackage --git-ignore-branch \
     --git-builder="dpkg-buildpackage --no-sign $DPKG_BUILDPACKAGE_ARGS" \
     $GBP_ARGS | tee -a "../$BUILD_LOG"
 else
   # Fall-back to plain dpkg-buildpackage if no git repository
-  dpkg-buildpackage --no-sign --build=any,all | tee -a "../$BUILD_LOG"
+  log_info "Running 'dpkg-buildpackage $DPKG_BUILDPACKAGE_ARGS' to create .deb packages from plain sources directory"
+  # shellcheck disable=SC2086 # intentionally pass variable that can be multiple arguments
+  dpkg-buildpackage --no-sign $DPKG_BUILDPACKAGE_ARGS | tee -a "../$BUILD_LOG"
 fi
 # @TODO: Test building just binaries to make build faster, and later also
 # test skipping rules/clean steps with '--no-pre-clean --no-post-clean'
