@@ -17,7 +17,7 @@ then
   log_info "Create local apt repository for testing newly built packages"
 
   mkdir -p /var/temp
-  cd /var/temp
+  cd /var/temp || (log_error "Unable to change directory to /var/temp"; exit 1)
   cp -a /tmp/build/previous-build/*.deb .
   apt-ftparchive packages . > Packages
   apt-ftparchive release . > Release
